from .. import setup_to_meta

class TestSetupToMeta:
    def test_del_substrings(self):
        """
        Test that del_substrings function properly deletes substrings from a given string
        """
        replaced = setup_to_meta.del_substrings('heallob, woarlcd', ['a', 'b', 'c'])
        assert replaced == 'hello, world'

    def test_get_names(self):
        """
        Test that setup_to_meta correctly gets the package name from the package path
        """
        d = 'apps/cli/executables/null'
        assert setup_to_meta.get_names([d]) == ['null']

    def test_get_dirs(self):
        """
        Test that setup_to_meta correctly finds and stores directory paths
        of packages containing setup.py files
        """
        assert './apps/cli/executables/null' in setup_to_meta.get_dirs()

    def test_get_outputs(self):
        """
        Test that tests that setup_to_meta correctly generates a list of output paths given
        a list of package names.
        """
        assert setup_to_meta.get_outputs(['null']) == ['build/metadata/null/meta.yaml']

    def test_output(self, recipe):
        """
        Test that metadata was successfully created and contains data.

        Checking for 'package' is an arbitrary check for content that will always
        occur in a correct recipe.
        :param recipe: Fixture that initializes recipe class in setup_to_meta.py
        """
        created = recipe.install()

        for path in created:
            with open(path, 'r') as f:
                assert 'package' in f.read()
